==> firefox-53.0.source.tar.xz: firefox-53.0/dom/media/ipc/VideoDecoderChild.h <==
/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* vim: set ts=8 sts=2 et sw=2 tw=99: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
#ifndef include_dom_ipc_VideoDecoderChild_h
#define include_dom_ipc_VideoDecoderChild_h

#include "mozilla/RefPtr.h"
#include "mozilla/dom/PVideoDecoderChild.h"
#include "MediaData.h"
#include "PlatformDecoderModule.h"

namespace mozilla {
namespace layers {
class SynchronousTask;
}
namespace dom {

class RemoteVideoDecoder;
class RemoteDecoderModule;
class VideoDecoderManagerChild;

class VideoDecoderChild final : public PVideoDecoderChild
{
public:
  explicit VideoDecoderChild();

  NS_INLINE_DECL_THREADSAFE_REFCOUNTING(VideoDecoderChild)

  // PVideoDecoderChild
  mozilla::ipc::IPCResult RecvOutput(const VideoDataIPDL& aData) override;
  mozilla::ipc::IPCResult RecvInputExhausted() override;
  mozilla::ipc::IPCResult RecvDrainComplete() override;
  mozilla::ipc::IPCResult RecvError(const nsresult& aError) override;
  mozilla::ipc::IPCResult RecvInitComplete(const bool& aHardware, const nsCString& aHardwareReason) override;
  mozilla::ipc::IPCResult RecvInitFailed(const nsresult& aReason) override;
  mozilla::ipc::IPCResult RecvFlushComplete() override;

  void ActorDestroy(ActorDestroyReason aWhy) override;

  RefPtr<MediaDataDecoder::InitPromise> Init();
  void Input(MediaRawData* aSample);
  void Flush(layers::SynchronousTask* Task);
  void Drain();
  void Shutdown();
  bool IsHardwareAccelerated(nsACString& aFailureReason) const;
  void SetSeekThreshold(const media::TimeUnit& aTime);

  MOZ_IS_CLASS_INIT
  bool InitIPDL(MediaDataDecoderCallback* aCallback,
                const VideoInfo& aVideoInfo,
                const layers::TextureFactoryIdentifier& aIdentifier);
  void DestroyIPDL();

  // Called from IPDL when our actor has been destroyed
  void IPDLActorDestroyed();

  VideoDecoderManagerChild* GetManager();

private:
  ~VideoDecoderChild();

  void AssertOnManagerThread();

  RefPtr<VideoDecoderChild> mIPDLSelfRef;
  RefPtr<nsIThread> mThread;

  MediaDataDecoderCallback* mCallback;

  MozPromiseHolder<MediaDataDecoder::InitPromise> mInitPromise;

  layers::SynchronousTask* mFlushTask;

  nsCString mHardwareAcceleratedReason;
  bool mCanSend;
  bool mInitialized;
  bool mIsHardwareAccelerated;
};

} // namespace dom
} // namespace mozilla

#endif // include_dom_ipc_VideoDecoderChild_h

==> firefox-54.0b1.source.tar.xz: firefox-54.0b1/dom/media/ipc/VideoDecoderChild.h <==
/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* vim: set ts=8 sts=2 et sw=2 tw=99: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
#ifndef include_dom_ipc_VideoDecoderChild_h
#define include_dom_ipc_VideoDecoderChild_h

#include "PlatformDecoderModule.h"
#include "mozilla/Atomics.h"
#include "mozilla/dom/PVideoDecoderChild.h"

namespace mozilla {
namespace dom {

class RemoteVideoDecoder;
class RemoteDecoderModule;
class VideoDecoderManagerChild;

class VideoDecoderChild final : public PVideoDecoderChild
{
public:
  explicit VideoDecoderChild();

  NS_INLINE_DECL_THREADSAFE_REFCOUNTING(VideoDecoderChild)

  // PVideoDecoderChild
  mozilla::ipc::IPCResult RecvOutput(const VideoDataIPDL& aData) override;
  mozilla::ipc::IPCResult RecvInputExhausted() override;
  mozilla::ipc::IPCResult RecvDrainComplete() override;
  mozilla::ipc::IPCResult RecvError(const nsresult& aError) override;
  mozilla::ipc::IPCResult RecvInitComplete(const bool& aHardware,
                                           const nsCString& aHardwareReason,
                                           const uint32_t& aConversion) override;
  mozilla::ipc::IPCResult RecvInitFailed(const nsresult& aReason) override;
  mozilla::ipc::IPCResult RecvFlushComplete() override;

  void ActorDestroy(ActorDestroyReason aWhy) override;

  RefPtr<MediaDataDecoder::InitPromise> Init();
  RefPtr<MediaDataDecoder::DecodePromise> Decode(MediaRawData* aSample);
  RefPtr<MediaDataDecoder::DecodePromise> Drain();
  RefPtr<MediaDataDecoder::FlushPromise> Flush();
  void Shutdown();
  bool IsHardwareAccelerated(nsACString& aFailureReason) const;
  void SetSeekThreshold(const media::TimeUnit& aTime);
  MediaDataDecoder::ConversionRequired NeedsConversion() const;

  MOZ_IS_CLASS_INIT
  bool InitIPDL(const VideoInfo& aVideoInfo,
                const layers::TextureFactoryIdentifier& aIdentifier);
  void DestroyIPDL();

  // Called from IPDL when our actor has been destroyed
  void IPDLActorDestroyed();

  VideoDecoderManagerChild* GetManager();

private:
  ~VideoDecoderChild();

  void AssertOnManagerThread() const;

  RefPtr<VideoDecoderChild> mIPDLSelfRef;
  RefPtr<nsIThread> mThread;

  MozPromiseHolder<MediaDataDecoder::InitPromise> mInitPromise;
  MozPromiseHolder<MediaDataDecoder::DecodePromise> mDecodePromise;
  MozPromiseHolder<MediaDataDecoder::DecodePromise> mDrainPromise;
  MozPromiseHolder<MediaDataDecoder::FlushPromise> mFlushPromise;

  nsCString mHardwareAcceleratedReason;
  bool mCanSend;
  bool mInitialized;
  Atomic<bool> mIsHardwareAccelerated;
  Atomic<MediaDataDecoder::ConversionRequired> mConversion;

  // Set to true if the actor got destroyed and we haven't yet notified the
  // caller.
  bool mNeedNewDecoder;
  MediaDataDecoder::DecodedData mDecodedData;
};

} // namespace dom
} // namespace mozilla

#endif // include_dom_ipc_VideoDecoderChild_h
